@@ -10,15 +10,15 @@
 #ifndef _OKULAR_ANNOTATIONS_H_
 #define _OKULAR_ANNOTATIONS_H_
 
-#include <QtCore/QString>
-#include <QtCore/QDateTime>
-#include <QtCore/QLinkedList>
-#include <QtCore/QRect>
-#include <QtGui/QFont>
-#include <QtXml/QDomDocument>
-#include <QtXml/QDomElement>
+#include <QString>
+#include <QDateTime>
+#include <QLinkedList>
+#include <QRect>
+#include <QFont>
+#include <QDomDocument>
+#include <QDomElement>
 
-#include "okular_export.h"
+#include "okularcore_export.h"
 #include "area.h"
 
 namespace Okular {
@@ -45,11 +45,12 @@ class SoundAnnotationPrivate;
 class MovieAnnotationPrivate;
 class ScreenAnnotationPrivate;
 class WidgetAnnotationPrivate;
+class RichMediaAnnotationPrivate;
 
 /**
  * @short Helper class for (recursive) annotation retrieval/storage.
  */
-class OKULAR_EXPORT AnnotationUtils
+class OKULARCORE_EXPORT AnnotationUtils
 {
     public:
         /**
@@ -87,7 +88,7 @@ class OKULAR_EXPORT AnnotationUtils
  * An Annotation is an object (text note, highlight, sound, popup window, ..)
  * contained by a Page in the document.
  */
-class OKULAR_EXPORT Annotation
+class OKULARCORE_EXPORT Annotation
 {
     /// @cond PRIVATE
     friend class AnnotationObjectRect;
@@ -116,6 +117,7 @@ class OKULAR_EXPORT Annotation
             AMovie = 11,    ///< A movie annotation
             AScreen = 12,   ///< A screen annotation
             AWidget = 13,   ///< A widget annotation
+            ARichMedia = 14,///< A rich media annotation
             A_BASE = 0      ///< The annotation base class
         };
 
@@ -133,7 +135,8 @@ class OKULAR_EXPORT Annotation
             ToggleHidingOnMouse = 64, ///< Can be hidden/shown by mouse click
             External = 128,           ///< Is stored external
             ExternallyDrawn = 256,    ///< Is drawn externally (by the generator which provided it) @since 0.10 (KDE 4.4)
-            BeingMoved = 512          ///< Is being moved (mouse drag and drop). If ExternallyDrawn, the generator must not draw it @since 0.15 (KDE 4.9)
+            BeingMoved = 512,         ///< Is being moved (mouse drag and drop). If ExternallyDrawn, the generator must not draw it @since 0.15 (KDE 4.9)
+            BeingResized = 1024       ///< Is being resized (mouse drag and drop). If ExternallyDrawn, the generator must not draw it @since 1.1.0
         };
 
         /**
@@ -144,7 +147,7 @@ class OKULAR_EXPORT Annotation
             Solid = 1,      ///< A solid line
             Dashed = 2,     ///< A dashed line
             Beveled = 4,    ///< A beveled line
-            Inset = 8,      ///< A inseted line
+            Inset = 8,      ///< An inset line
             Underline = 16  ///< An underline
         };
 
@@ -188,8 +191,14 @@ class OKULAR_EXPORT Annotation
          */
         enum AdditionalActionType
         {
-            PageOpening, ///< Performed when the page containing the annotation is opened.
-            PageClosing  ///< Performed when the page containing the annotation is closed.
+            PageOpening,    ///< Performed when the page containing the annotation is opened.
+            PageClosing,    ///< Performed when the page containing the annotation is closed.
+            CursorEntering, ///< Performed when the cursor enters the annotation's active area @since 1.5
+            CursorLeaving,  ///< Performed when the cursor exists the annotation's active area @since 1.5
+            MousePressed,   ///< Performed when the mouse button is pressed inside the annotation's active area @since 1.5
+            MouseReleased,  ///< Performed when the mouse button is released inside the annotation's active area @since 1.5
+            FocusIn,        ///< Performed when the annotation receives the input focus @since 1.5
+            FocusOut,       ///< Performed when the annotation loses the input focus @since 1.5
         };
 
         /**
@@ -298,11 +307,20 @@ class OKULAR_EXPORT Annotation
          */
         void translate( const NormalizedPoint &coord );
 
+        /**
+         * Adjust the annotation by the specified coordinates.
+         * Adds coordinates of @p deltaCoord1 to annotations top left corner,
+         * and @p deltaCoord2 to the bottom right.
+         *
+         * @see canBeResized()
+         */
+        void adjust( const NormalizedPoint & deltaCoord1, const NormalizedPoint & deltaCoord2 );
+
         /**
          * The Style class contains all information about style of the
          * annotation.
          */
-        class OKULAR_EXPORT Style
+        class OKULARCORE_EXPORT Style
         {
             public:
                 /**
@@ -437,7 +455,7 @@ class OKULAR_EXPORT Annotation
          * The Window class contains all information about the popup window
          * of the annotation that is used to edit the content and properties.
          */
-        class OKULAR_EXPORT Window
+        class OKULARCORE_EXPORT Window
         {
             public:
                 /**
@@ -632,6 +650,11 @@ class OKULAR_EXPORT Annotation
          */
         bool canBeMoved() const;
 
+        /**
+         * Returns whether the annotation can be resized.
+         */
+        bool canBeResized() const;
+
         /**
          * Returns whether the annotation dialog should be open after creation of the annotation or not
          *
@@ -683,7 +706,7 @@ class OKULAR_EXPORT Annotation
  *
  * @since 0.15 (KDE 4.9)
  */
-class OKULAR_EXPORT AnnotationProxy
+class OKULARCORE_EXPORT AnnotationProxy
 {
     public:
         enum Capability
@@ -714,7 +737,7 @@ class OKULAR_EXPORT AnnotationProxy
          * Called after an existing @p annotation at a given @p page is modified.
          *
          * Generator can call @p annotation getters to get the new values.
-         * @p appearanceChanged tells if a non-visible property was modifed
+         * @p appearanceChanged tells if a non-visible property was modified
          *
          * @note Only called if supports(Modification) == true
          */
@@ -728,7 +751,7 @@ class OKULAR_EXPORT AnnotationProxy
         virtual void notifyRemoval( Annotation *annotation, int page ) = 0;
 };
 
-class OKULAR_EXPORT TextAnnotation : public Annotation
+class OKULARCORE_EXPORT TextAnnotation : public Annotation
 {
     public:
         /**
@@ -758,7 +781,7 @@ class OKULAR_EXPORT TextAnnotation : public Annotation
         /**
          * Creates a new text annotation from the xml @p description
          */
-        TextAnnotation( const QDomNode &description );
+        explicit TextAnnotation( const QDomNode &description );
 
         /**
          * Destroys the text annotation.
@@ -796,6 +819,20 @@ class OKULAR_EXPORT TextAnnotation : public Annotation
          */
         QFont textFont() const;
 
+        /**
+         * Sets the @p color of inplace text.
+         *
+         * @since 1.6
+         */
+        void setTextColor( const QColor &color );
+
+        /**
+         * Returns the color of inplace text.
+         *
+         * @since 1.6
+         */
+        QColor textColor() const;
+
         /**
          * Sets the inplace @p alignment of the text annotation.
          */
@@ -841,19 +878,19 @@ class OKULAR_EXPORT TextAnnotation : public Annotation
         /**
          * Returns the sub type of the text annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the text annotation as xml in @p document under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( TextAnnotation )
         Q_DISABLE_COPY( TextAnnotation )
 };
 
-class OKULAR_EXPORT LineAnnotation : public Annotation
+class OKULARCORE_EXPORT LineAnnotation : public Annotation
 {
     public:
         /**
@@ -1001,19 +1038,19 @@ class OKULAR_EXPORT LineAnnotation : public Annotation
         /**
          * Returns the sub type of the line annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the line annotation as xml in @p document under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( LineAnnotation )
         Q_DISABLE_COPY( LineAnnotation )
 };
 
-class OKULAR_EXPORT GeomAnnotation : public Annotation
+class OKULARCORE_EXPORT GeomAnnotation : public Annotation
 {
     public:
         // common enums
@@ -1031,7 +1068,7 @@ class OKULAR_EXPORT GeomAnnotation : public Annotation
         /**
          * Creates a new geometrical annotation from the xml @p description
          */
-        GeomAnnotation( const QDomNode &description );
+        explicit GeomAnnotation( const QDomNode &description );
 
         /**
          * Destroys the geometrical annotation.
@@ -1062,20 +1099,20 @@ class OKULAR_EXPORT GeomAnnotation : public Annotation
         /**
          * Returns the sub type of the geometrical annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the geometrical annotation as xml in @p document
          * under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( GeomAnnotation )
         Q_DISABLE_COPY( GeomAnnotation )
 };
 
-class OKULAR_EXPORT HighlightAnnotation : public Annotation
+class OKULARCORE_EXPORT HighlightAnnotation : public Annotation
 {
     public:
         /**
@@ -1119,7 +1156,7 @@ class OKULAR_EXPORT HighlightAnnotation : public Annotation
          * The Quad class contains 8 coordinates and style definitions
          * which describe a line part of the whole highlight annotation.
          */
-        class OKULAR_EXPORT Quad
+        class OKULARCORE_EXPORT Quad
         {
             public:
                 /**
@@ -1205,20 +1242,20 @@ class OKULAR_EXPORT HighlightAnnotation : public Annotation
         /**
          * Returns the sub type of the highlight annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the highlight annotation as xml in @p document
          * under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( HighlightAnnotation )
         Q_DISABLE_COPY( HighlightAnnotation )
 };
 
-class OKULAR_EXPORT StampAnnotation : public Annotation
+class OKULARCORE_EXPORT StampAnnotation : public Annotation
 {
     public:
         /**
@@ -1249,20 +1286,20 @@ class OKULAR_EXPORT StampAnnotation : public Annotation
         /**
          * Returns the sub type of the stamp annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the stamp annotation as xml in @p document
          * under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( StampAnnotation )
         Q_DISABLE_COPY( StampAnnotation )
 };
 
-class OKULAR_EXPORT InkAnnotation : public Annotation
+class OKULARCORE_EXPORT InkAnnotation : public Annotation
 {
     public:
         /**
@@ -1273,7 +1310,7 @@ class OKULAR_EXPORT InkAnnotation : public Annotation
         /**
          * Creates a new ink annotation from the xml @p description
          */
-        InkAnnotation( const QDomNode &description );
+        explicit InkAnnotation( const QDomNode &description );
 
         /**
          * Destroys the ink annotation.
@@ -1299,20 +1336,20 @@ class OKULAR_EXPORT InkAnnotation : public Annotation
         /**
          * Returns the sub type of the ink annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the ink annotation as xml in @p document
          * under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( InkAnnotation )
         Q_DISABLE_COPY( InkAnnotation )
 };
 
-class OKULAR_EXPORT CaretAnnotation : public Annotation
+class OKULARCORE_EXPORT CaretAnnotation : public Annotation
 {
     public:
         /**
@@ -1352,20 +1389,20 @@ class OKULAR_EXPORT CaretAnnotation : public Annotation
         /**
          * Returns the sub type of the caret annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the caret annotation as xml in @p document
          * under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( CaretAnnotation )
         Q_DISABLE_COPY( CaretAnnotation )
 };
 
-class OKULAR_EXPORT FileAttachmentAnnotation : public Annotation
+class OKULARCORE_EXPORT FileAttachmentAnnotation : public Annotation
 {
     public:
         /**
@@ -1405,13 +1442,13 @@ class OKULAR_EXPORT FileAttachmentAnnotation : public Annotation
         /**
          * Returns the sub type of the file attachment annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the file attachment annotation as xml in @p document
          * under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( FileAttachmentAnnotation )
@@ -1425,7 +1462,7 @@ class OKULAR_EXPORT FileAttachmentAnnotation : public Annotation
  *
  * @since 0.7 (KDE 4.1)
  */
-class OKULAR_EXPORT SoundAnnotation : public Annotation
+class OKULARCORE_EXPORT SoundAnnotation : public Annotation
 {
     public:
         /**
@@ -1435,7 +1472,7 @@ class OKULAR_EXPORT SoundAnnotation : public Annotation
         /**
          * Creates a new sound annotation from the xml @p description
          */
-        SoundAnnotation( const QDomNode &description );
+        explicit SoundAnnotation( const QDomNode &description );
         /**
          * Destroys the sound annotation.
          */
@@ -1465,13 +1502,13 @@ class OKULAR_EXPORT SoundAnnotation : public Annotation
         /**
          * Returns the sub type of the sound annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the sound annotation as xml in @p document
          * under the given parent @p node.
          */
-        void store( QDomNode &node, QDomDocument &document ) const;
+        void store( QDomNode &node, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( SoundAnnotation )
@@ -1485,7 +1522,7 @@ class OKULAR_EXPORT SoundAnnotation : public Annotation
  *
  * @since 0.8 (KDE 4.2)
  */
-class OKULAR_EXPORT MovieAnnotation : public Annotation
+class OKULARCORE_EXPORT MovieAnnotation : public Annotation
 {
     public:
         /**
@@ -1495,7 +1532,7 @@ class OKULAR_EXPORT MovieAnnotation : public Annotation
         /**
          * Creates a new movie annotation from the xml @p description
          */
-        MovieAnnotation( const QDomNode &description );
+        explicit MovieAnnotation( const QDomNode &description );
         /**
          * Destroys the movie annotation.
          */
@@ -1511,12 +1548,12 @@ class OKULAR_EXPORT MovieAnnotation : public Annotation
         /**
          * Returns the sub type of the movie annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
         /**
          * Stores the movie annotation as xml in @p document
          * under the given @p parentNode.
          */
-        void store( QDomNode &parentNode, QDomDocument &document ) const;
+        void store( QDomNode &parentNode, QDomDocument &document ) const override;
 
     private:
         Q_DECLARE_PRIVATE( MovieAnnotation )
@@ -1531,7 +1568,7 @@ class OKULAR_EXPORT MovieAnnotation : public Annotation
  *
  * @since 0.16 (KDE 4.10)
  */
-class OKULAR_EXPORT ScreenAnnotation : public Annotation
+class OKULARCORE_EXPORT ScreenAnnotation : public Annotation
 {
     public:
         /**
@@ -1542,7 +1579,7 @@ class OKULAR_EXPORT ScreenAnnotation : public Annotation
         /**
          * Creates a new screen annotation from the xml @p description
          */
-        ScreenAnnotation( const QDomNode &description );
+        explicit ScreenAnnotation( const QDomNode &description );
 
         /**
          * Destroys the screen annotation.
@@ -1552,13 +1589,13 @@ class OKULAR_EXPORT ScreenAnnotation : public Annotation
         /**
          * Returns the sub type of the screen annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the screen annotation as xml in @p document
          * under the given @p parentNode.
          */
-        void store( QDomNode &parentNode, QDomDocument &document ) const;
+        void store( QDomNode &parentNode, QDomDocument &document ) const override;
 
         /**
          * Sets the @p action that is executed when the annotation is triggered.
@@ -1600,7 +1637,7 @@ class OKULAR_EXPORT ScreenAnnotation : public Annotation
  *
  * @since 0.16 (KDE 4.10)
  */
-class OKULAR_EXPORT WidgetAnnotation : public Annotation
+class OKULARCORE_EXPORT WidgetAnnotation : public Annotation
 {
     public:
         /**
@@ -1611,7 +1648,7 @@ class OKULAR_EXPORT WidgetAnnotation : public Annotation
         /**
          * Creates a new widget annotation from the xml @p description
          */
-        WidgetAnnotation( const QDomNode &description );
+        explicit WidgetAnnotation( const QDomNode &description );
 
         /**
          * Destroys the widget annotation.
@@ -1621,13 +1658,13 @@ class OKULAR_EXPORT WidgetAnnotation : public Annotation
         /**
          * Returns the sub type of the widget annotation.
          */
-        SubType subType() const;
+        SubType subType() const override;
 
         /**
          * Stores the widget annotation as xml in @p document
          * under the given @p parentNode.
          */
-        void store( QDomNode &parentNode, QDomDocument &document ) const;
+        void store( QDomNode &parentNode, QDomDocument &document ) const override;
 
         /**
          * Sets the additional @p action of the given @p type.
@@ -1648,6 +1685,67 @@ class OKULAR_EXPORT WidgetAnnotation : public Annotation
         Q_DISABLE_COPY( WidgetAnnotation )
 };
 
+/**
+ * \short RichMedia annotation.
+ *
+ * The rich media annotation represents an video or sound on a page.
+ *
+ * @since 1.0
+ */
+class OKULARCORE_EXPORT RichMediaAnnotation : public Annotation
+{
+    public:
+        /**
+         * Creates a new rich media annotation.
+         */
+        RichMediaAnnotation();
+
+        /**
+         * Creates a new rich media annotation from the xml @p description
+         */
+        explicit RichMediaAnnotation( const QDomNode &description );
+
+        /**
+         * Destroys the rich media annotation.
+         */
+        virtual ~RichMediaAnnotation();
+
+        /**
+         * Returns the sub type of the rich media annotation.
+         */
+        SubType subType() const override;
+
+        /**
+         * Stores the rich media annotation as xml in @p document
+         * under the given @p parentNode.
+         */
+        void store( QDomNode &parentNode, QDomDocument &document ) const override;
+
+        /**
+         * Gets the movie object.
+         */
+        Movie* movie() const;
+
+        /**
+         * Sets the new @p movie object.
+         */
+        void setMovie( Movie *movie );
+
+        /**
+         * Sets the @p object representing the embedded file.
+         */
+        void setEmbeddedFile( EmbeddedFile *object );
+
+        /**
+         * Gets the embedded file object.
+         */
+        EmbeddedFile* embeddedFile() const;
+
+    private:
+        Q_DECLARE_PRIVATE( RichMediaAnnotation )
+        Q_DISABLE_COPY( RichMediaAnnotation )
+};
+
 }
 
 #endif
