@@ -2068,12 +2068,7 @@ XpsGenerator::XpsGenerator( QObject *parent, const QVariantList &args )
     setFeature( TextExtraction );
     setFeature( PrintNative );
     setFeature( PrintToFile );
-    // activate the threaded rendering iif:
-    // 1) QFontDatabase says so
-    // 2) Qt >= 4.4.0 (see Trolltech task ID: 169502)
-    // 3) Qt >= 4.4.2 (see Trolltech task ID: 215090)
-    if ( QFontDatabase::supportsThreadedFontRendering() )
-        setFeature( Threaded );
+    setFeature( Threaded );
     userMutex();
 }
 
