@@ -99,6 +99,9 @@ struct XpsPathGeometry
         qDeleteAll( paths );
     }
 
+    XpsPathGeometry(const XpsPathGeometry &) = delete;
+    XpsPathGeometry &operator=(const XpsPathGeometry &) = delete;
+
     QList< XpsPathFigure* > paths;
     Qt::FillRule fillRule;
     XpsMatrixTransform transform;
@@ -128,7 +131,7 @@ protected:
     void processStartElement( XpsRenderNode &node );
     void processEndElement( XpsRenderNode &node );
 
-    // Methods for processing of diferent xml elements
+    // Methods for processing of different xml elements
     void processGlyph( XpsRenderNode &node );
     void processPath( XpsRenderNode &node );
     void processPathData( XpsRenderNode &node );
@@ -153,6 +156,9 @@ public:
     XpsPage(XpsFile *file, const QString &fileName);
     ~XpsPage();
 
+    XpsPage(const XpsPage &) = delete;
+    XpsPage &operator=(const XpsPage &) = delete;
+
     QSizeF size() const;
     bool renderToImage( QImage *p );
     bool renderToPainter( QPainter *painter );
@@ -189,6 +195,9 @@ public:
     XpsDocument(XpsFile *file, const QString &fileName);
     ~XpsDocument();
 
+    XpsDocument(const XpsDocument &) = delete;
+    XpsDocument &operator=(const XpsDocument &) = delete;
+
     /**
        the total number of pages in this document
     */
@@ -234,6 +243,9 @@ public:
     XpsFile();
     ~XpsFile();
 
+    XpsFile(const XpsFile &) = delete;
+    XpsFile &operator=(const XpsFile &) = delete;
+
     bool loadDocument( const QString & fileName );
     bool closeDocument();
 
